@@ -93,26 +93,6 @@
         <source>&amp;Help</source>
         <translation>Көмек</translation>
     </message>
-    <message numerus="yes">
-        <source>%n hour(s)</source>
-        <translation><numerusform>%n сағат</numerusform></translation>
-    </message>
-    <message numerus="yes">
-        <source>%n day(s)</source>
-        <translation><numerusform>%n күн</numerusform></translation>
-    </message>
-    <message numerus="yes">
-        <source>%n week(s)</source>
-        <translation><numerusform>%n апта</numerusform></translation>
-    </message>
-    <message>
-        <source>%1 and %2</source>
-        <translation>%1 немесе %2</translation>
-    </message>
-    <message numerus="yes">
-        <source>%n year(s)</source>
-        <translation><numerusform>%n жыл</numerusform></translation>
-    </message>
     <message>
         <source>%1 behind</source>
         <translation>%1 қалмады</translation>
@@ -140,10 +120,6 @@
         <source>Amount:</source>
         <translation>Саны</translation>
     </message>
-    <message>
-        <source>Priority:</source>
-        <translation>Басымдық</translation>
-    </message>
     <message>
         <source>Fee:</source>
         <translation>Комиссия</translation>
@@ -172,10 +148,6 @@
         <source>Confirmed</source>
         <translation>Растық</translation>
     </message>
-    <message>
-        <source>Priority</source>
-        <translation>Басымдық</translation>
-    </message>
     </context>
 <context>
     <name>EditAddressDialog</name>
@@ -196,11 +168,18 @@
     </context>
 <context>
     <name>Intro</name>
+    <message>
+        <source>Bitcoin</source>
+        <translation>Биткоин</translation>
+    </message>
     <message>
         <source>Error</source>
         <translation>қате</translation>
     </message>
     </context>
+<context>
+    <name>ModalOverlay</name>
+    </context>
 <context>
     <name>OpenURIDialog</name>
     </context>
@@ -210,6 +189,10 @@
         <source>W&amp;allet</source>
         <translation>Әмиян</translation>
     </message>
+    <message>
+        <source>Error</source>
+        <translation>қате</translation>
+    </message>
     </context>
 <context>
     <name>OverviewPage</name>
@@ -226,6 +209,13 @@
         <source>Amount</source>
         <translation>Саны</translation>
     </message>
+    <message>
+        <source>%1 and %2</source>
+        <translation>%1 немесе %2</translation>
+    </message>
+    </context>
+<context>
+    <name>QObject::QObject</name>
     </context>
 <context>
     <name>QRImageWidget</name>
@@ -246,6 +236,10 @@
     </context>
 <context>
     <name>ReceiveRequestDialog</name>
+    <message>
+        <source>Wallet</source>
+        <translation>Әмиян</translation>
+    </message>
     </context>
 <context>
     <name>RecentRequestsTableModel</name>
@@ -256,10 +250,6 @@
         <source>Amount:</source>
         <translation>Саны</translation>
     </message>
-    <message>
-        <source>Priority:</source>
-        <translation>Басымдық</translation>
-    </message>
     <message>
         <source>Fee:</source>
         <translation>Комиссия:</translation>
