@@ -29,6 +29,10 @@
         <source>Delete the currently selected address from the list</source>
         <translation>Обришите тренутно одабрану адресу са листе</translation>
     </message>
+    <message>
+        <source>Enter address or label to search</source>
+        <translation>Navedite adresu ili naziv koji bi ste potražili</translation>
+    </message>
     <message>
         <source>Export the data in the current tab to a file</source>
         <translation>Извези податке из одабране картице у фајлj</translation>
@@ -321,6 +325,14 @@
         <source>Open &amp;URI...</source>
         <translation>Отвори &amp;УРИ...</translation>
     </message>
+    <message>
+        <source>Wallet:</source>
+        <translation>Новчаник</translation>
+    </message>
+    <message>
+        <source>default wallet</source>
+        <translation>подразумевани новчаник</translation>
+    </message>
     <message>
         <source>Click to disable network activity.</source>
         <translation>Кликни да искључиш активност на мрежи.</translation>
@@ -341,6 +353,10 @@
         <source>Reindexing blocks on disk...</source>
         <translation>Поново идексирање блокова на диску.</translation>
     </message>
+    <message>
+        <source>Proxy is &lt;b&gt;enabled&lt;/b&gt;: %1</source>
+        <translation>Прокси је &lt;b&gt;омогућен&lt;/b&gt;: %1</translation>
+    </message>
     <message>
         <source>Send coins to a Bitcoin address</source>
         <translation>Пошаљите новац на Биткоин адресу</translation>
@@ -437,6 +453,10 @@
         <source>&amp;Command-line options</source>
         <translation>&amp;Опције командне линије</translation>
     </message>
+    <message numerus="yes">
+        <source>%n active connection(s) to Bitcoin network</source>
+        <translation><numerusform>%n aктивна веза са Биткоин мрежом</numerusform><numerusform>%n aктивних веза са Биткоин мрежом</numerusform><numerusform>%n aктивних веза са Биткоин мрежом</numerusform></translation>
+    </message>
     <message>
         <source>Indexing blocks on disk...</source>
         <translation>Идексирање блокова на диску...</translation>
@@ -477,6 +497,10 @@
         <source>Up to date</source>
         <translation>Ажурно</translation>
     </message>
+    <message>
+        <source>Show the %1 help message to get a list with possible Bitcoin command-line options</source>
+        <translation>Прикажи  поруку помоћи %1 за листу са могућим опцијама Биткоин командне линије</translation>
+    </message>
     <message>
         <source>%1 client</source>
         <translation>%1 клијент</translation>
@@ -495,6 +519,12 @@
         <source>Amount: %1
 </source>
         <translation>Износ: %1
+</translation>
+    </message>
+    <message>
+        <source>Wallet: %1
+</source>
+        <translation>Новчаник: %1
 </translation>
     </message>
     <message>
@@ -698,10 +728,6 @@
         <source>&amp;Address</source>
         <translation>&amp;Адреса</translation>
     </message>
-    <message>
-        <source>New receiving address</source>
-        <translation>Нова адреса за пријем</translation>
-    </message>
     <message>
         <source>New sending address</source>
         <translation>Нова адреса за слање</translation>
@@ -714,10 +740,6 @@
         <source>Edit sending address</source>
         <translation>Измени адресу за слање</translation>
     </message>
-    <message>
-        <source>The entered address "%1" is already in the address book.</source>
-        <translation>Унета адреса "%1" се већ налази у адресару.</translation>
-    </message>
     <message>
         <source>Could not unlock wallet.</source>
         <translation>Новчаник није могуће откључати.</translation>
@@ -768,19 +790,7 @@
         <source>Command-line options</source>
         <translation>Опције командне линије</translation>
     </message>
-    <message>
-        <source>Usage:</source>
-        <translation>Korišćenje:</translation>
-    </message>
-    <message>
-        <source>command-line options</source>
-        <translation>опције командне линије</translation>
-    </message>
-    <message>
-        <source>Choose data directory on startup (default: %u)</source>
-        <translation>Изаберите директоријум података при покретању (подразумевано: %u)</translation>
-    </message>
-    </context>
+</context>
 <context>
     <name>Intro</name>
     <message>
@@ -953,6 +963,10 @@
         <source>Last block time</source>
         <translation>Време последњег блока</translation>
     </message>
+    <message>
+        <source>default wallet</source>
+        <translation>подразумевани новчаник</translation>
+    </message>
     <message>
         <source>Yes</source>
         <translation>Da</translation>
@@ -1008,6 +1022,10 @@
         <source>Label</source>
         <translation>Налепница</translation>
     </message>
+    <message>
+        <source>Wallet</source>
+        <translation>Новчаник</translation>
+    </message>
     </context>
 <context>
     <name>RecentRequestsTableModel</name>
@@ -1232,38 +1250,14 @@
     </context>
 <context>
     <name>bitcoin-core</name>
-    <message>
-        <source>Options:</source>
-        <translation>Opcije</translation>
-    </message>
-    <message>
-        <source>Specify data directory</source>
-        <translation>Gde je konkretni data direktorijum </translation>
-    </message>
-    <message>
-        <source>Accept command line and JSON-RPC commands</source>
-        <translation>Prihvati komandnu liniju i JSON-RPC komande</translation>
-    </message>
-    <message>
-        <source>Run in the background as a daemon and accept commands</source>
-        <translation>Radi u pozadini kao daemon servis i prihvati komande</translation>
-    </message>
     <message>
         <source>Information</source>
         <translation>Информације</translation>
     </message>
-    <message>
-        <source>Username for JSON-RPC connections</source>
-        <translation>Korisničko ime za JSON-RPC konekcije</translation>
-    </message>
     <message>
         <source>Warning</source>
         <translation>Упозорење</translation>
     </message>
-    <message>
-        <source>Password for JSON-RPC connections</source>
-        <translation>Lozinka za JSON-RPC konekcije</translation>
-    </message>
     <message>
         <source>Insufficient funds</source>
         <translation>Nedovoljno sredstava</translation>
