@@ -445,10 +445,6 @@
         <source>&amp;Address</source>
         <translation>Adres</translation>
     </message>
-    <message>
-        <source>New receiving address</source>
-        <translation>Yeni alış adresi</translation>
-    </message>
     <message>
         <source>New sending address</source>
         <translation>Yeni gönderim adresi</translation>
@@ -465,10 +461,6 @@
         <source>The entered address "%1" is not a valid Bitcoin address.</source>
         <translation>Girilen adres "%1" Bitcoin adresiyle eşleşmiyor.</translation>
     </message>
-    <message>
-        <source>The entered address "%1" is already in the address book.</source>
-        <translation>Girilen adres "%1" adres defterinde zaten kayıtlı.</translation>
-    </message>
     <message>
         <source>New key generation failed.</source>
         <translation>Yeni anahtar üretimi başarısız.</translation>
@@ -495,23 +487,7 @@
         <source>Command-line options</source>
         <translation>Komut satırı ayarları</translation>
     </message>
-    <message>
-        <source>Usage:</source>
-        <translation>Kullanım:</translation>
-    </message>
-    <message>
-        <source>command-line options</source>
-        <translation>komut satırı ayarları</translation>
-    </message>
-    <message>
-        <source>UI Options:</source>
-        <translation>UI Ayarları:</translation>
-    </message>
-    <message>
-        <source>Set language, for example "de_DE" (default: system locale)</source>
-        <translation>Bir dil seçin, örneğin "de_DE" (seçilen: Sistem dili)</translation>
-    </message>
-    </context>
+</context>
 <context>
     <name>Intro</name>
     <message>
@@ -1011,6 +987,10 @@
         <source>Message</source>
         <translation>Mesaj</translation>
     </message>
+    <message>
+        <source>Wallet</source>
+        <translation>Cüzdan</translation>
+    </message>
     </context>
 <context>
     <name>RecentRequestsTableModel</name>
@@ -1105,6 +1085,10 @@
         <source>or</source>
         <translation>ya da</translation>
     </message>
+    <message>
+        <source>Transaction fee</source>
+        <translation>Gönderim ücreti</translation>
+    </message>
     <message>
         <source>Confirm send coins</source>
         <translation>Coin gönderimini onaylayın</translation>
@@ -1402,38 +1386,14 @@
     </context>
 <context>
     <name>bitcoin-core</name>
-    <message>
-        <source>Options:</source>
-        <translation>Ayarlar:</translation>
-    </message>
-    <message>
-        <source>Accept command line and JSON-RPC commands</source>
-        <translation>JSON-RPC komutları ile komut satırını onaylayın</translation>
-    </message>
     <message>
         <source>Bitcoin Core</source>
         <translation>Bitcoin Çekirdeği</translation>
     </message>
-    <message>
-        <source>&lt;category&gt; can be:</source>
-        <translation>&lt;category&gt; can be:</translation>
-    </message>
-    <message>
-        <source>Block creation options:</source>
-        <translation>Blok oluşturma ayarları:</translation>
-    </message>
-    <message>
-        <source>Connection options:</source>
-        <translation>Bağlantı ayarları:</translation>
-    </message>
     <message>
         <source>Copyright (C) %i-%i</source>
         <translation>Copyright (C) %i-%i</translation>
     </message>
-    <message>
-        <source>Debugging/Testing options:</source>
-        <translation>Hata giderme/test ayarları:</translation>
-    </message>
     <message>
         <source>Error: Disk space is low!</source>
         <translation>Hata: Disk boyutu düşük!</translation>
@@ -1446,14 +1406,6 @@
         <source>Loading banlist...</source>
         <translation>Ban listesi yükleniyor...</translation>
     </message>
-    <message>
-        <source>Print this help message and exit</source>
-        <translation>Bu yardım mesajını yazdır ve çıkış yap</translation>
-    </message>
-    <message>
-        <source>Print version and exit</source>
-        <translation>Versiyonu yazdır ve çıkış yap</translation>
-    </message>
     <message>
         <source>Verifying blocks...</source>
         <translation>Bloklar Onaylanıyor...</translation>
@@ -1462,14 +1414,6 @@
         <source>Wallet needed to be rewritten: restart %s to complete</source>
         <translation>%s tamamlanması için cüzdanın yeniden başlatılması gerekiyor</translation>
     </message>
-    <message>
-        <source>Wallet options:</source>
-        <translation>Cüzdan Ayarları</translation>
-    </message>
-    <message>
-        <source>(default: %u)</source>
-        <translation>(varsayılan: %u)</translation>
-    </message>
     <message>
         <source>Error reading from database, shutting down.</source>
         <translation>Veritabanı okuma hatası, kapatıldı.</translation>
@@ -1482,26 +1426,14 @@
         <source>Invalid -onion address or hostname: '%s'</source>
         <translation>Hatalı -onion adresi ya da host adı: '%s'</translation>
     </message>
-    <message>
-        <source>RPC server options:</source>
-        <translation>RPC sunucu ayarları</translation>
-    </message>
     <message>
         <source>This is experimental software.</source>
         <translation>Bu deneysel bir yazılımdır.</translation>
     </message>
-    <message>
-        <source>Tor control port password (default: empty)</source>
-        <translation>Tor kontrolü portu şifresi (varsayılan: boş bırakınız)</translation>
-    </message>
     <message>
         <source>Transaction too large</source>
         <translation>İşlem çok büyük</translation>
     </message>
-    <message>
-        <source>Username for JSON-RPC connections</source>
-        <translation>JSON-RPC bağlantıları için kullanıcı adı</translation>
-    </message>
     <message>
         <source>Verifying wallet(s)...</source>
         <translation>Cüzdan(lar) onaylanıyor...</translation>
@@ -1510,30 +1442,6 @@
         <source>Warning</source>
         <translation>Uyarı</translation>
     </message>
-    <message>
-        <source>Password for JSON-RPC connections</source>
-        <translation>JSON-RPC bağlantıları için şifre</translation>
-    </message>
-    <message>
-        <source>(default: %s)</source>
-        <translation>(varsayılan: %s)</translation>
-    </message>
-    <message>
-        <source>Specify configuration file (default: %s)</source>
-        <translation>Yapılandırma dosyasını belirle (varsayılan: %s)</translation>
-    </message>
-    <message>
-        <source>Specify connection timeout in milliseconds (minimum: 1, default: %d)</source>
-        <translation>Milisaniyelik zaman aşımına uğramış bağlantıyı belirle (minimum: 1, varsayılan: %d)</translation>
-    </message>
-    <message>
-        <source>Specify pid file (default: %s)</source>
-        <translation>Pid dosyasını belirle (Varsayılan: %s)</translation>
-    </message>
-    <message>
-        <source>Spend unconfirmed change when sending transactions (default: %u)</source>
-        <translation>İşlem gönderiminde onaylanmamış değişimi öde (Varsayılan: %u)</translation>
-    </message>
     <message>
         <source>Starting network threads...</source>
         <translation>Bağlantı konuları başlıyor</translation>
@@ -1550,10 +1458,6 @@
         <source>This is the transaction fee you will pay if you send a transaction.</source>
         <translation>Bir işlem göndermeniz durumunda işlem ücretiniz budur</translation>
     </message>
-    <message>
-        <source>Threshold for disconnecting misbehaving peers (default: %u)</source>
-        <translation>Sorunlu emsalleri koparma eşiği (Varsayılan: %u)</translation>
-    </message>
     <message>
         <source>Transaction amounts must not be negative</source>
         <translation>İşlem miktarı negatif olmamalı</translation>
